==========
 Examples
==========

.. _examples:

These files can be found in the doc/source/examples directory of
the git source of this project.  They can also be found at the
`online git repository`_ of this project.

.. _online git repository: https://opendev.org/openstack/oslo.context/src/branch/master/doc/source/user/examples


.. _example_usage_simple.py:

usage_simple.py
---------------

.. highlight:: python
.. literalinclude:: examples/usage_simple.py
   :linenos:

.. _example_usage.py:

usage.py
--------

.. literalinclude:: examples/usage.py
   :linenos:

.. _example_usage_user_identity.py:

usage_user_identity.py
----------------------

.. literalinclude:: examples/usage_user_identity.py
   :linenos:
